@@ -349,10 +349,9 @@ def _get_file_text(context, path, content):
 def _get_any(context, path, content, type, mimetype, format, decode):
     method = 'GET' if content else 'HEAD'
     key = _key(context, path)
-    print('key',key)
     response = yield _get_object(context, context.s3_bucket, key)
     print(response)
-    file_bytes = response['Body']
+    file_bytes = response['Body'].read()
     last_modified_str = response['LastModified']
     if not isinstance(last_modified_str, str):
         last_modified = f"{datetime.datetime.now():%a, %d %b %Y %H:%M:%S GMT}"
